==> react-hr-component-kc-1.0.38.tgz: package/src/components/UpdatePlanetTest.js <==
import React, { useState, useEffect } from "react";
import LeftNavigationUiConfiguratorTest from "./LeftNavigationUiConfiguratorTest";
import { Form, Row, Col, Button } from "react-bootstrap";
import { FaEdit, FaUserAlt, FaBan } from "react-icons/fa";
import { Link, NavLink } from "react-router-dom";
import Alert from "react-bootstrap/Alert";
import Axios from "axios";

function UpdatePlanetTest(props) {
  const [planetInfoData, setPlanetInfoData] = useState({
    planetId: "",
    planetDesc: "",
    mgmtServerLocation: "",
    credential: "",
    orgs: [
      {
        id: "",
        orgName: "",
        credential: "",
        env: [
          {
            id: "",
            name: "",
            vhost: [
              {
                id: "",
                envName: "",
                name: "",
                protocol: "",
                port: "",
                cname: "",
              },
            ],
          },
        ],
      },
    ],
  });

  //load existing planet details
  useEffect(() => {
    axios
      .get("https://configurator-api-m7mkmev5sq-uc.a.run.app/planet/1")
      .then((response) => {
        setPlanetInfoData({
          planetId: response.data.planetId,
          planetDesc: response.data.planetDesc,
          mgmtServerLocation: response.data.mgmtServerLocation,
          credential: response.data.credential,
          orgs: response.data.orgs.map((od, idx) => ({
            id: od.id,
            orgName: od.orgName,
            credential: od.credential,
            env: od.env.map((envd, indx) => ({
              id: envd.id,
              name: envd.name,
              vhost: envd.vhost.map((vd, ixd) => ({
                id: vd.id,
                envName: vd.envName,
                name: vd.name,
                protocol: vd.protocol,
                port: vd.port,
                cname: vd.cname,
              })),
            })),
          })),
        });
      });
  }, []);

  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Update Planet</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/">Update Planet</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">{props.leftNavigation}</div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div className="mb-3">
                      <Form>
                        <Form.Group as={Row} controlId="planetDesc">
                          <Form.Label column sm={2}>
                            Planet Description{" "}
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="planetDesc"
                              //onChange={handlePlanetDescriptionChange}
                              value={planetInfoData.planetDesc}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="mgmtServerLocation">
                          <Form.Label column sm={2}>
                            Management Server Location
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="mgmtServerLocation"
                              //onChange={handleMgmtServerLocationChange}
                              value={planetInfoData.mgmtServerLocation}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="credential">
                          <Form.Label column sm={2}>
                            Credential
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="credential"
                              //onChange={handleCredentialChange}
                              value={planetInfoData.credential}
                            />
                          </Col>
                        </Form.Group>
                        <div className="group-field-highlight-pattern-info ">
                          <p>Orgs</p>
                          <Button variant="primary">+ Add new org</Button>
                        </div>

                        {planetInfoData.orgs.map((branch, i) => (
                          <div>
                            {branch.orgName}
                            <span className="action-pad">
                              <Link to="/">
                                <FaEdit />
                              </Link>
                            </span>
                            {/* <Form.Group as={Row} controlId="entityPatternName">
                              <Form.Label column sm={2}>
                                Pattern Name <span className="required">*</span>
                              </Form.Label>
                              <Col sm={10}>
                                <Form.Control
                                  type="text"
                                  className="w-75"
                                  name="entityPatternName"
                                  onChange={(e) =>
                                    handlePatternNameChange(e, i)
                                  }
                                  value={
                                    entityDeploymentData.entityBranchMappings[i]
                                      .entityPatternName
                                  }
                                />
                              </Col>
                            </Form.Group> */}

                            {/* <Button
                                variant="secondary"
                                onClick={(e) => deletePattern(e, i)}
                              >
                                -Pattern
                              </Button> */}
                            {/* {branch.entityDeploymentInfo.map((host, j) => (
                                <div className="group-field-highlight-org-info">
                                  <Form.Group as={Row} controlId="entityOrg">
                                    <Form.Label column sm={2}>
                                      Org <span className="required">*</span>
                                    </Form.Label>
                                    <Col sm={10}>
                                      <div className="row org-button">
                                        <Form.Control
                                          type="text"
                                          className="w-75"
                                          name="entityOrg"
                                          onChange={(e) =>
                                            handleEntityOrgChange(e, i, j)
                                          }
                                          value={
                                            entityDeploymentData
                                              .entityBranchMappings[i]
                                              .entityDeploymentInfo[j].entityOrg
                                          }
                                        />
                                        <Button
                                          variant="secondary"
                                          onClick={(e) => deleteOrg(e, i, j)}
                                        >
                                          -Org
                                        </Button>
                                      </div>
                                    </Col>
                                  </Form.Group>
                                  <Form.Group
                                    as={Row}
                                    controlId="entityEnvironment"
                                  >
                                    <Form.Label column sm={2}>
                                      Env <span className="required">*</span>
                                    </Form.Label>
                                    <Col sm={10}>
                                      <Form.Control
                                        type="text"
                                        className="w-75"
                                        name="entityEnvironment"
                                        onChange={(e) =>
                                          handleEntityEnvironmentChange(e, i, j)
                                        }
                                        value={
                                          entityDeploymentData
                                            .entityBranchMappings[i]
                                            .entityDeploymentInfo[j]
                                            .entityEnvironment
                                        }
                                      />
                                    </Col>
                                  </Form.Group>
                                  <Form.Group as={Row} controlId="entityHost">
                                    <Form.Label column sm={2}>
                                      Host <span className="required">*</span>
                                    </Form.Label>
                                    <Col sm={10}>
                                      <Form.Control
                                        type="text"
                                        className="w-75"
                                        name="entityHost"
                                        onChange={(e) =>
                                          handleEntityHostChange(e, i, j)
                                        }
                                        value={
                                          entityDeploymentData
                                            .entityBranchMappings[i]
                                            .entityDeploymentInfo[j].entityHost
                                        }
                                      />
                                    </Col>
                                  </Form.Group>
                                </div>
                              ))} */}
                            {/* <Button
                              variant="primary"
                              onClick={(e) => addOrg(e, i)}
                            >
                              +Org
                            </Button> */}
                          </div>
                        ))}
                      </Form>
                      {/* <Button variant="primary" onClick={addPattern}>
                        +Pattern
                      </Button>{" "} */}
                      <br />
                      <br />
                      <Button variant="primary">Update</Button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default UpdatePlanetTest;

==> react-hr-component-kc-1.0.40.tgz: package/src/components/UpdatePlanetTest.js <==
import React, { useState, useEffect } from "react";
import LeftNavigationUiConfiguratorTest from "./LeftNavigationUiConfiguratorTest";
import { Form, Row, Col, Button } from "react-bootstrap";
import { FaEdit, FaUserAlt, FaBan } from "react-icons/fa";
import { Link, NavLink } from "react-router-dom";
import Alert from "react-bootstrap/Alert";
import axios from "axios";

function UpdatePlanetTest(props) {
  const [planetInfoData, setPlanetInfoData] = useState({
    planetId: "",
    planetDesc: "",
    mgmtServerLocation: "",
    credential: "",
    orgs: [
      {
        id: "",
        orgName: "",
        credential: "",
        env: [
          {
            id: "",
            name: "",
            vhost: [
              {
                id: "",
                envName: "",
                name: "",
                protocol: "",
                port: "",
                cname: "",
              },
            ],
          },
        ],
      },
    ],
  });

  //load existing planet details
  useEffect(() => {
    axios
      .get("https://configurator-api-m7mkmev5sq-uc.a.run.app/planet/1")
      .then((response) => {
        setPlanetInfoData({
          planetId: response.data.planetId,
          planetDesc: response.data.planetDesc,
          mgmtServerLocation: response.data.mgmtServerLocation,
          credential: response.data.credential,
          orgs: response.data.orgs.map((od, idx) => ({
            id: od.id,
            orgName: od.orgName,
            credential: od.credential,
            env: od.env.map((envd, indx) => ({
              id: envd.id,
              name: envd.name,
              vhost: envd.vhost.map((vd, ixd) => ({
                id: vd.id,
                envName: vd.envName,
                name: vd.name,
                protocol: vd.protocol,
                port: vd.port,
                cname: vd.cname,
              })),
            })),
          })),
        });
      });
  }, []);

  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Update Planet</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/">Update Planet</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">{props.leftNavigation}</div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div className="mb-3">
                      <Form>
                        <Form.Group as={Row} controlId="planetDesc">
                          <Form.Label column sm={2}>
                            Planet Description{" "}
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="planetDesc"
                              //onChange={handlePlanetDescriptionChange}
                              value={planetInfoData.planetDesc}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="mgmtServerLocation">
                          <Form.Label column sm={2}>
                            Management Server Location
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="mgmtServerLocation"
                              //onChange={handleMgmtServerLocationChange}
                              value={planetInfoData.mgmtServerLocation}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="credential">
                          <Form.Label column sm={2}>
                            Credential
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="credential"
                              //onChange={handleCredentialChange}
                              value={planetInfoData.credential}
                            />
                          </Col>
                        </Form.Group>
                        <div className="group-field-highlight-pattern-info ">
                          <p>Orgs</p>

                          {planetInfoData.orgs.map((branch, i) => (
                            <div>
                              {branch.orgName}
                              <span className="action-pad">
                                <Link to="/">
                                  <FaEdit />
                                </Link>
                              </span>
                            </div>
                          ))}
                          <Button variant="primary">+ Add new org</Button>
                        </div>
                      </Form>
                      {/* <Button variant="primary" onClick={addPattern}>
                        +Pattern
                      </Button>{" "} */}
                      <br />
                      <br />
                      <Button variant="primary">Update</Button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default UpdatePlanetTest;
